CREATE TABLE PaymentMethod
(
PaymentMethod NVARCHAR2(50),
     CONSTRAINT pk_PaymentMethod PRIMARY KEY (PaymentMethod)
);

CREATE TABLE ProductCategory
(
Category      NVARCHAR2(50),
CategoryDescription         NVARCHAR2(250),
     CONSTRAINT pk_ProductCategory PRIMARY KEY (Category)
);

CREATE TABLE SkiBoardStyle
(
Style         NVARCHAR2(50),
StyleDescription            NVARCHAR2(150),
Category      NVARCHAR2(50),
     CONSTRAINT pk_SkiBoardStyle PRIMARY KEY (Style),
     CONSTRAINT fk_ProdCatSkiBoardStyle FOREIGN KEY (Category)
        REFERENCES ProductCategory(Category)
        ON DELETE CASCADE
);

CREATE TABLE SkillLevel
(
SkillLevel    INTEGER
     DEFAULT 0,
Description   NVARCHAR2(150),
     CONSTRAINT pk_SkillLevel PRIMARY KEY (SkillLevel)
);

CREATE TABLE BindingStyle
(
BindingStyle  NVARCHAR2(50),
Description   NVARCHAR2(150),
Style         NVARCHAR2(50),
     CONSTRAINT pk_BindingStyle PRIMARY KEY (BindingStyle),
     CONSTRAINT fk_SkiBrdStyleBindStyle FOREIGN KEY (Style)
        REFERENCES SkiBoardStyle(Style)
        ON DELETE CASCADE
);

CREATE TABLE Customer
(
CustomerID    INTEGER,
LastName      NVARCHAR2(50),
FirstName     NVARCHAR2(50),
Phone         NVARCHAR2(50),
EMail         NVARCHAR2(120),
Address       NVARCHAR2(50),
City          NVARCHAR2(50),
State         NVARCHAR2(50),
ZIP           NVARCHAR2(50),
Gender        NVARCHAR2(50)
     CHECK (Gender IN ('Female', 'Male', 'Unidentified')),
DateOfBirth   DATE,
     CONSTRAINT pk_Customer PRIMARY KEY (CustomerID)
);

CREATE TABLE CustomerSkill
(
CustomerID    INTEGER
     DEFAULT 0,
Style         NVARCHAR2(50),
SkillLevel    INTEGER
     DEFAULT 0,
SkillComments NVARCHAR2(250),
     CONSTRAINT pk_CustomerSkill PRIMARY KEY (CustomerID,Style),
     CONSTRAINT fk_CustomerCustomerSkill FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_SkiBoardStyleCustSkill FOREIGN KEY (Style)
        REFERENCES SkiBoardStyle(Style)
        ON DELETE CASCADE,
     CONSTRAINT fk_SkillLevelCustSkill FOREIGN KEY (SkillLevel)
        REFERENCES SkillLevel(SkillLevel)
        ON DELETE CASCADE
);

CREATE TABLE Department
(
Department    NVARCHAR2(50),
Description   NVARCHAR2(150),
     CONSTRAINT pk_Department PRIMARY KEY (Department)
);

CREATE TABLE Employee
(
EmployeeID    INTEGER,
TaxpayerID    NVARCHAR2(50),
LastName      NVARCHAR2(50),
FirstName     NVARCHAR2(50),
Address       NVARCHAR2(50),
Phone         NVARCHAR2(50),
City          NVARCHAR2(50),
State         NVARCHAR2(50),
ZIP           NVARCHAR2(50),
Department    NVARCHAR2(50),
     CONSTRAINT pk_Employee PRIMARY KEY (EmployeeID),
     CONSTRAINT fk_DepartmentEmployee FOREIGN KEY (Department)
        REFERENCES Department(Department)
        ON DELETE CASCADE
);

CREATE TABLE Manufacturer
(
ManufacturerID              INTEGER,
Name          NVARCHAR2(50),
Address       NVARCHAR2(50),
City          NVARCHAR2(50),
State         NVARCHAR2(50),
ZIP           NVARCHAR2(50),
Phone         NVARCHAR2(50),
EMail         NVARCHAR2(150),
Category      NVARCHAR2(50),
     CONSTRAINT pk_Manufacturer PRIMARY KEY (ManufacturerID),
     CONSTRAINT fk_ProdCatManuf FOREIGN KEY (Category)
        REFERENCES ProductCategory(Category)
        ON DELETE CASCADE
);

CREATE TABLE ItemModel
(
ModelID       NVARCHAR2(50),
ManufacturerID              INTEGER
     DEFAULT 0,
Category      NVARCHAR2(50),
Color         NVARCHAR2(50),
Cost          NUMBER(38,4)
     DEFAULT 0,
ModelYear     INTEGER
     DEFAULT 0,
Graphics      NVARCHAR2(50),
ItemMaterial  NVARCHAR2(50),
ListPrice     NUMBER(38,4)
     DEFAULT 0,
Style         NVARCHAR2(50),
SkillLevel    INTEGER,
WeightMax     NUMBER,
WeightMin     NUMBER,
WaistWidth    NUMBER,
EffectiveEdge NUMBER,
BindingStyle  NVARCHAR2(50),
RentalRate    NUMBER(38,4),
     CONSTRAINT pk_ItemModel PRIMARY KEY (ModelID),
     CONSTRAINT fk_BindingStyleItemModel FOREIGN KEY (BindingStyle)
        REFERENCES BindingStyle(BindingStyle)
        ON DELETE CASCADE,
     CONSTRAINT fk_ManufacturerItemModel FOREIGN KEY (ManufacturerID)
        REFERENCES Manufacturer(ManufacturerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_ProdCatItemModel FOREIGN KEY (Category)
        REFERENCES ProductCategory(Category)
        ON DELETE CASCADE,
     CONSTRAINT fk_SkiBrdStyleItemModel FOREIGN KEY (Style)
        REFERENCES SkiBoardStyle(Style)
        ON DELETE CASCADE,
     CONSTRAINT fk_SkillLevelItemModel FOREIGN KEY (SkillLevel)
        REFERENCES SkillLevel(SkillLevel)
        ON DELETE CASCADE
);

CREATE TABLE Inventory
(
SKU           NVARCHAR2(50),
ModelID       NVARCHAR2(50),
ItemSize      NUMBER
     DEFAULT 0,
QuantityOnHand              INTEGER
     DEFAULT 0,
     CONSTRAINT pk_Inventory PRIMARY KEY (SKU),
     CONSTRAINT fk_ItemModelInventory FOREIGN KEY (ModelID)
        REFERENCES ItemModel(ModelID)
        ON DELETE CASCADE
);


CREATE TABLE Rental
(
RentID        INTEGER,
RentDate      DATE,
CustomerID    INTEGER
     DEFAULT 0,
ExpectedReturn              DATE,
PaymentMethod NVARCHAR2(50),
     CONSTRAINT pk_Rental PRIMARY KEY (RentID),
     CONSTRAINT fk_CustomerRental FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_PaymentMethodRental FOREIGN KEY (PaymentMethod)
        REFERENCES PaymentMethod(PaymentMethod)
        ON DELETE CASCADE
);

CREATE TABLE RentItem
(
RentID        INTEGER
     DEFAULT 0,
SKU           NVARCHAR2(50),
RentFee       NUMBER(38,4)
     DEFAULT 0,
ReturnDate    DATE,
ReturnCondition             NVARCHAR2(150),
RepairCharges NUMBER(38,4)
     DEFAULT 0,
     CONSTRAINT pk_RentItem PRIMARY KEY (RentID,SKU),
     CONSTRAINT fk_InventoryRentItem FOREIGN KEY (SKU)
        REFERENCES Inventory(SKU)
        ON DELETE CASCADE,
     CONSTRAINT fk_RentalRentItem FOREIGN KEY (RentID)
        REFERENCES Rental(RentID)
        ON DELETE CASCADE
);

CREATE TABLE Sale
(
SaleID        INTEGER,
SaleDate      DATE,
CustomerID    INTEGER
     DEFAULT 0,
EmployeeID    INTEGER
     DEFAULT 0,
ShipAddress   NVARCHAR2(50),
ShipCity      NVARCHAR2(50),
ShipState     NVARCHAR2(50),
ShipZIP       NVARCHAR2(50),
SalesTax      NUMBER(38,4)
     DEFAULT 0,
PaymentMethod NVARCHAR2(50),
     CONSTRAINT pk_Sale PRIMARY KEY (SaleID),
     CONSTRAINT fk_CustomerSale FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_PaymentMethodSale FOREIGN KEY (PaymentMethod)
        REFERENCES PaymentMethod(PaymentMethod)
        ON DELETE CASCADE
);

CREATE TABLE SaleItem
(
SaleID        INTEGER
     DEFAULT 0,
SKU           NVARCHAR2(50),
QuantitySold  INTEGER
     DEFAULT 0,
SalePrice     NUMBER(38,4)
     DEFAULT 0,
     CONSTRAINT pk_SaleItem PRIMARY KEY (SaleID,SKU),
     CONSTRAINT fk_InventorySaleItem FOREIGN KEY (SKU)
        REFERENCES Inventory(SKU)
        ON DELETE CASCADE,
     CONSTRAINT fk_SaleSaleItem FOREIGN KEY (SaleID)
        REFERENCES Sale(SaleID)
        ON DELETE CASCADE
);
